slepc-3.18.0 2022-10-01
Report Typos and Errors

# MFNGetOptionsPrefix

Gets the prefix used for searching for all MFN options in the database.

### Synopsis

    #include "slepcmfn.h"
    PetscErrorCode MFNGetOptionsPrefix(MFN mfn,const char *prefix[])

Not Collective

### Input Parameters

| mfn | - the matrix function context

### Output Parameters

| prefix | - pointer to the prefix string used is returned

### Note

On the Fortran side, the user should pass in a string 'prefix' of sufficient length to hold the prefix.

### See Also

MFNSetOptionsPrefix(), MFNAppendOptionsPrefix()

### Level

advanced

### Location

src/mfn/interface/mfnopts.c
Index of all MFN routines
Table of Contents for all manual pages
Index of all manual pages